@@ -17,14 +17,14 @@ def _get_kwargs(
     client: AuthenticatedClient,
     json_body: ApplicationIn,
     get_if_exists: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -72,7 +72,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     json_body: ApplicationIn,
     get_if_exists: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ApplicationOut:
     """Create Application
 
@@ -81,7 +81,7 @@ def sync_detailed(
     Args:
         get_if_exists (Union[Unset, None, bool]): Get an existing application, or create a new one
             if doesn't exist. It's two separate functions in the libs.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ApplicationIn):
 
     Returns:
@@ -119,7 +119,7 @@ def sync(
     client: AuthenticatedClient,
     json_body: ApplicationIn,
     get_if_exists: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ApplicationOut:
     """Create Application
 
@@ -128,7 +128,7 @@ def sync(
     Args:
         get_if_exists (Union[Unset, None, bool]): Get an existing application, or create a new one
             if doesn't exist. It's two separate functions in the libs.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ApplicationIn):
 
     Returns:
@@ -148,7 +148,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     json_body: ApplicationIn,
     get_if_exists: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ApplicationOut:
     """Create Application
 
@@ -157,7 +157,7 @@ async def asyncio_detailed(
     Args:
         get_if_exists (Union[Unset, None, bool]): Get an existing application, or create a new one
             if doesn't exist. It's two separate functions in the libs.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ApplicationIn):
 
     Returns:
@@ -193,7 +193,7 @@ async def asyncio(
     client: AuthenticatedClient,
     json_body: ApplicationIn,
     get_if_exists: Union[Unset, None, bool] = False,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ApplicationOut:
     """Create Application
 
@@ -202,7 +202,7 @@ async def asyncio(
     Args:
         get_if_exists (Union[Unset, None, bool]): Get an existing application, or create a new one
             if doesn't exist. It's two separate functions in the libs.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ApplicationIn):
 
     Returns:
