@@ -16,14 +16,14 @@ def _get_kwargs(
     *,
     client: AuthenticatedClient,
     json_body: ExportEnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/environment/export/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     json_json_body = json_body
@@ -64,14 +64,14 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     json_body: ExportEnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EnvironmentOut:
     """Export Environment Configuration
 
      Download a JSON file containing all org-settings and event types
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ExportEnvironmentIn):
 
     Returns:
@@ -107,14 +107,14 @@ def sync(
     *,
     client: AuthenticatedClient,
     json_body: ExportEnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EnvironmentOut:
     """Export Environment Configuration
 
      Download a JSON file containing all org-settings and event types
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ExportEnvironmentIn):
 
     Returns:
@@ -132,14 +132,14 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     json_body: ExportEnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EnvironmentOut:
     """Export Environment Configuration
 
      Download a JSON file containing all org-settings and event types
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ExportEnvironmentIn):
 
     Returns:
@@ -173,14 +173,14 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     json_body: ExportEnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EnvironmentOut:
     """Export Environment Configuration
 
      Download a JSON file containing all org-settings and event types
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (ExportEnvironmentIn):
 
     Returns:
