@@ -16,14 +16,14 @@ def _get_kwargs(
     *,
     client: Client,
     json_body: EventTypeSchemaIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/event-type/schema/generate-example/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     json_json_body = json_body.to_dict()
@@ -64,14 +64,14 @@ def sync_detailed(
     *,
     client: Client,
     json_body: EventTypeSchemaIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeExampleOut:
     """Generate Schema Example
 
      Generates a fake example from the given JSONSchema
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeSchemaIn):
 
     Returns:
@@ -107,14 +107,14 @@ def sync(
     *,
     client: Client,
     json_body: EventTypeSchemaIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeExampleOut:
     """Generate Schema Example
 
      Generates a fake example from the given JSONSchema
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeSchemaIn):
 
     Returns:
@@ -132,14 +132,14 @@ async def asyncio_detailed(
     *,
     client: Client,
     json_body: EventTypeSchemaIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeExampleOut:
     """Generate Schema Example
 
      Generates a fake example from the given JSONSchema
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeSchemaIn):
 
     Returns:
@@ -173,14 +173,14 @@ async def asyncio(
     *,
     client: Client,
     json_body: EventTypeSchemaIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeExampleOut:
     """Generate Schema Example
 
      Generates a fake example from the given JSONSchema
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeSchemaIn):
 
     Returns:
