@@ -28,14 +28,14 @@ def _get_kwargs(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/attempt/msg/{msg_id}/".format(client.base_url, app_id=app_id, msg_id=msg_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -128,7 +128,7 @@ def sync_detailed(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Msg
 
@@ -158,7 +158,7 @@ def sync_detailed(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -213,7 +213,7 @@ def sync(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Msg
 
@@ -243,7 +243,7 @@ def sync(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -280,7 +280,7 @@ async def asyncio_detailed(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Msg
 
@@ -310,7 +310,7 @@ async def asyncio_detailed(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -363,7 +363,7 @@ async def asyncio(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Msg
 
@@ -393,7 +393,7 @@ async def asyncio(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
