@@ -2,6 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
+from ..models.application_in_metadata import ApplicationInMetadata
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ApplicationIn")
@@ -12,17 +13,20 @@ class ApplicationIn:
     """
     Attributes:
         name (str):  Example: My first application.
+        metadata (Union[Unset, None, ApplicationInMetadata]):
         rate_limit (Union[Unset, None, int]):  Example: 1000.
         uid (Union[Unset, None, str]): Optional unique identifier for the application Example: unique-app-identifier.
     """
 
     name: str
+    metadata: Union[Unset, None, ApplicationInMetadata] = UNSET
     rate_limit: Union[Unset, None, int] = UNSET
     uid: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         name = self.name
+        metadata = self.metadata
         rate_limit = self.rate_limit
         uid = self.uid
 
@@ -33,6 +37,8 @@ class ApplicationIn:
                 "name": name,
             }
         )
+        if metadata is not UNSET:
+            field_dict["metadata"] = metadata
         if rate_limit is not UNSET:
             field_dict["rateLimit"] = rate_limit
         if uid is not UNSET:
@@ -45,12 +51,15 @@ class ApplicationIn:
         dict_copy = src_dict.copy()
         name = dict_copy.pop("name")
 
+        metadata = dict_copy.pop("metadata")
+
         rate_limit = dict_copy.pop("rateLimit", UNSET)
 
         uid = dict_copy.pop("uid", UNSET)
 
         application_in = cls(
             name=name,
+            metadata=metadata,
             rate_limit=rate_limit,
             uid=uid,
         )
