@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 import attr
 from dateutil.parser import isoparse
 
+from ..models.application_out_metadata import ApplicationOutMetadata
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ApplicationOut")
@@ -17,6 +18,7 @@ class ApplicationOut:
         id (str):  Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         name (str):  Example: My first application.
         updated_at (datetime.datetime):
+        metadata (Union[Unset, None, ApplicationOutMetadata]):
         rate_limit (Union[Unset, None, int]):  Example: 1000.
         uid (Union[Unset, None, str]): Optional unique identifier for the application Example: unique-app-identifier.
     """
@@ -25,6 +27,7 @@ class ApplicationOut:
     id: str
     name: str
     updated_at: datetime.datetime
+    metadata: Union[Unset, None, ApplicationOutMetadata] = UNSET
     rate_limit: Union[Unset, None, int] = UNSET
     uid: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -36,6 +39,7 @@ class ApplicationOut:
         name = self.name
         updated_at = self.updated_at.isoformat()
 
+        metadata = self.metadata
         rate_limit = self.rate_limit
         uid = self.uid
 
@@ -49,6 +53,8 @@ class ApplicationOut:
                 "updatedAt": updated_at,
             }
         )
+        if metadata is not UNSET:
+            field_dict["metadata"] = metadata
         if rate_limit is not UNSET:
             field_dict["rateLimit"] = rate_limit
         if uid is not UNSET:
@@ -67,6 +73,8 @@ class ApplicationOut:
 
         updated_at = isoparse(dict_copy.pop("updatedAt"))
 
+        metadata = dict_copy.pop("metadata")
+
         rate_limit = dict_copy.pop("rateLimit", UNSET)
 
         uid = dict_copy.pop("uid", UNSET)
@@ -76,6 +84,7 @@ class ApplicationOut:
             id=id,
             name=name,
             updated_at=updated_at,
+            metadata=metadata,
             rate_limit=rate_limit,
             uid=uid,
         )
