@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 import attr
 from dateutil.parser import isoparse
 
+from ..models.endpoint_out_metadata import EndpointOutMetadata
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="EndpointOut")
@@ -23,6 +24,7 @@ class EndpointOut:
         description (Union[Unset, str]):  Default: ''. Example: An example endpoint name.
         disabled (Union[Unset, bool]):
         filter_types (Union[Unset, None, List[str]]):  Example: ['user.signup', 'user.deleted'].
+        metadata (Union[Unset, None, EndpointOutMetadata]):
         rate_limit (Union[Unset, None, int]):  Example: 1000.
         uid (Union[Unset, None, str]): Optional unique identifier for the endpoint Example: unique-endpoint-identifier.
     """
@@ -36,6 +38,7 @@ class EndpointOut:
     description: Union[Unset, str] = ""
     disabled: Union[Unset, bool] = False
     filter_types: Union[Unset, None, List[str]] = UNSET
+    metadata: Union[Unset, None, EndpointOutMetadata] = UNSET
     rate_limit: Union[Unset, None, int] = UNSET
     uid: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -64,6 +67,7 @@ class EndpointOut:
             else:
                 filter_types = self.filter_types
 
+        metadata = self.metadata
         rate_limit = self.rate_limit
         uid = self.uid
 
@@ -86,6 +90,8 @@ class EndpointOut:
             field_dict["disabled"] = disabled
         if filter_types is not UNSET:
             field_dict["filterTypes"] = filter_types
+        if metadata is not UNSET:
+            field_dict["metadata"] = metadata
         if rate_limit is not UNSET:
             field_dict["rateLimit"] = rate_limit
         if uid is not UNSET:
@@ -114,6 +120,8 @@ class EndpointOut:
 
         filter_types = cast(List[str], dict_copy.pop("filterTypes", UNSET))
 
+        metadata = dict_copy.pop("metadata")
+
         rate_limit = dict_copy.pop("rateLimit", UNSET)
 
         uid = dict_copy.pop("uid", UNSET)
@@ -128,6 +136,7 @@ class EndpointOut:
             description=description,
             disabled=disabled,
             filter_types=filter_types,
+            metadata=metadata,
             rate_limit=rate_limit,
             uid=uid,
         )
