@@ -2,6 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
+from ..models.endpoint_update_metadata import EndpointUpdateMetadata
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="EndpointUpdate")
@@ -18,6 +19,7 @@ class EndpointUpdate:
         description (Union[Unset, str]):  Default: ''. Example: An example endpoint name.
         disabled (Union[Unset, bool]):
         filter_types (Union[Unset, None, List[str]]):  Example: ['user.signup', 'user.deleted'].
+        metadata (Union[Unset, None, EndpointUpdateMetadata]):
         rate_limit (Union[Unset, None, int]):  Example: 1000.
         uid (Union[Unset, None, str]): Optional unique identifier for the endpoint Example: unique-endpoint-identifier.
     """
@@ -28,6 +30,7 @@ class EndpointUpdate:
     description: Union[Unset, str] = ""
     disabled: Union[Unset, bool] = False
     filter_types: Union[Unset, None, List[str]] = UNSET
+    metadata: Union[Unset, None, EndpointUpdateMetadata] = UNSET
     rate_limit: Union[Unset, None, int] = UNSET
     uid: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -51,6 +54,7 @@ class EndpointUpdate:
             else:
                 filter_types = self.filter_types
 
+        metadata = self.metadata
         rate_limit = self.rate_limit
         uid = self.uid
 
@@ -70,6 +74,8 @@ class EndpointUpdate:
             field_dict["disabled"] = disabled
         if filter_types is not UNSET:
             field_dict["filterTypes"] = filter_types
+        if metadata is not UNSET:
+            field_dict["metadata"] = metadata
         if rate_limit is not UNSET:
             field_dict["rateLimit"] = rate_limit
         if uid is not UNSET:
@@ -92,6 +98,8 @@ class EndpointUpdate:
 
         filter_types = cast(List[str], dict_copy.pop("filterTypes", UNSET))
 
+        metadata = dict_copy.pop("metadata")
+
         rate_limit = dict_copy.pop("rateLimit", UNSET)
 
         uid = dict_copy.pop("uid", UNSET)
@@ -103,6 +111,7 @@ class EndpointUpdate:
             description=description,
             disabled=disabled,
             filter_types=filter_types,
+            metadata=metadata,
             rate_limit=rate_limit,
             uid=uid,
         )
