@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 import attr
 from dateutil.parser import isoparse
 
+from ..models.message_endpoint_out_metadata import MessageEndpointOutMetadata
 from ..models.message_status import MessageStatus
 from ..types import UNSET, Unset
 
@@ -28,6 +29,7 @@ class MessageEndpointOut:
         description (Union[Unset, str]):  Default: ''. Example: An example endpoint name.
         disabled (Union[Unset, bool]):
         filter_types (Union[Unset, None, List[str]]):  Example: ['user.signup', 'user.deleted'].
+        metadata (Union[Unset, None, MessageEndpointOutMetadata]):
         next_attempt (Union[Unset, None, datetime.datetime]):
         rate_limit (Union[Unset, None, int]):  Example: 1000.
         uid (Union[Unset, None, str]): Optional unique identifier for the endpoint Example: unique-endpoint-identifier.
@@ -42,6 +44,7 @@ class MessageEndpointOut:
     description: Union[Unset, str] = ""
     disabled: Union[Unset, bool] = False
     filter_types: Union[Unset, None, List[str]] = UNSET
+    metadata: Union[Unset, None, MessageEndpointOutMetadata] = UNSET
     next_attempt: Union[Unset, None, datetime.datetime] = UNSET
     rate_limit: Union[Unset, None, int] = UNSET
     uid: Union[Unset, None, str] = UNSET
@@ -71,6 +74,7 @@ class MessageEndpointOut:
             else:
                 filter_types = self.filter_types
 
+        metadata = self.metadata
         next_attempt: Union[Unset, None, str] = UNSET
         if not isinstance(self.next_attempt, Unset):
             next_attempt = self.next_attempt.isoformat() if self.next_attempt else None
@@ -97,6 +101,8 @@ class MessageEndpointOut:
             field_dict["disabled"] = disabled
         if filter_types is not UNSET:
             field_dict["filterTypes"] = filter_types
+        if metadata is not UNSET:
+            field_dict["metadata"] = metadata
         if next_attempt is not UNSET:
             field_dict["nextAttempt"] = next_attempt
         if rate_limit is not UNSET:
@@ -127,6 +133,8 @@ class MessageEndpointOut:
 
         filter_types = cast(List[str], dict_copy.pop("filterTypes", UNSET))
 
+        metadata = dict_copy.pop("metadata")
+
         _next_attempt = dict_copy.pop("nextAttempt", UNSET)
         next_attempt: Union[Unset, None, datetime.datetime]
         if _next_attempt is None:
@@ -150,6 +158,7 @@ class MessageEndpointOut:
             description=description,
             disabled=disabled,
             filter_types=filter_types,
+            metadata=metadata,
             next_attempt=next_attempt,
             rate_limit=rate_limit,
             uid=uid,
