@@ -27,6 +27,7 @@ class SettingsIn:
         enable_transformations (Union[Unset, bool]):
         enforce_https (Union[Unset, bool]):  Default: True.
         event_catalog_published (Union[Unset, None, bool]):
+        read_only (Union[Unset, bool]):
     """
 
     color_palette_dark: Union[Unset, CustomColorPalette] = UNSET
@@ -43,6 +44,7 @@ class SettingsIn:
     enable_transformations: Union[Unset, bool] = False
     enforce_https: Union[Unset, bool] = True
     event_catalog_published: Union[Unset, None, bool] = False
+    read_only: Union[Unset, bool] = False
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -69,6 +71,7 @@ class SettingsIn:
         enable_transformations = self.enable_transformations
         enforce_https = self.enforce_https
         event_catalog_published = self.event_catalog_published
+        read_only = self.read_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -101,6 +104,8 @@ class SettingsIn:
             field_dict["enforceHttps"] = enforce_https
         if event_catalog_published is not UNSET:
             field_dict["eventCatalogPublished"] = event_catalog_published
+        if read_only is not UNSET:
+            field_dict["readOnly"] = read_only
 
         return field_dict
 
@@ -150,6 +155,8 @@ class SettingsIn:
 
         event_catalog_published = dict_copy.pop("eventCatalogPublished", UNSET)
 
+        read_only = dict_copy.pop("readOnly", UNSET)
+
         settings_in = cls(
             color_palette_dark=color_palette_dark,
             color_palette_light=color_palette_light,
@@ -165,6 +172,7 @@ class SettingsIn:
             enable_transformations=enable_transformations,
             enforce_https=enforce_https,
             event_catalog_published=event_catalog_published,
+            read_only=read_only,
         )
 
         settings_in.additional_properties = dict_copy
